import { renderless, api } from '@opentinyvue/vue-renderless/dropdown/vue';
import { defineComponent, $prefix, directive, setup, h, $props } from '@opentinyvue/vue-common';
import Button from '@opentinyvue/vue-button';
import ButtonGroup from '@opentinyvue/vue-button-group';
import { Clickoutside } from '@opentinyvue/vue-directive';
import DropdownMenu from '@opentinyvue/vue-dropdown-menu';
import { iconDownWard } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var __vue2_script = defineComponent({
  name: $prefix + "Dropdown",
  componentName: "TinyDropdown",
  components: {
    TinyButton: Button,
    TinyButtonGroup: ButtonGroup,
    TinyDropdownMenu: DropdownMenu,
    IconDownWard: iconDownWard()
  },
  directives: directive({
    Clickoutside
  }),
  props: _extends({}, $props, {
    type: String,
    trigger: String,
    // tiny新增
    visible: {
      type: [Boolean, void 0],
      default: void 0
    },
    size: {
      type: String,
      default: ""
    },
    disabled: {
      type: Boolean,
      default: false
    },
    splitButton: Boolean,
    showTimeout: {
      type: Number,
      default: 250
    },
    hideTimeout: {
      type: Number,
      default: 150
    },
    hideOnClick: {
      type: Boolean,
      default: true
    },
    tabindex: {
      type: Number,
      default: 0
    },
    border: {
      type: Boolean,
      default: false
    },
    round: {
      type: Boolean,
      default: false
    },
    showIcon: {
      type: Boolean,
      default: true
    },
    menuOptions: {
      type: Object,
      default: function _default() {
        return {
          options: [],
          textField: "label",
          popperClass: "",
          placement: "bottom-end"
        };
      }
    },
    title: {
      type: String,
      default: "下拉菜单"
      // TINY-TODO: 国际化
    },
    inheritWidth: {
      type: Boolean,
      default: false
    },
    suffixIcon: Object,
    prefixIcon: Object,
    lazyShowPopper: {
      type: Boolean,
      default: false
    }
  }),
  emits: ["visible-change", "item-click", "button-click", "menu-item-click", "handle-click", "is-disabled", "selected-index", "update:visible"],
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      h
    });
  },
  render: function render() {
    var _state$designConfig, _state$designConfig$i, _state$designConfig2, _state$designConfig2$;
    var h2 = arguments[0];
    var splitButton = this.splitButton, type = this.type, disabled = this.disabled, handleMainButtonClick = this.handleMainButtonClick, menuOptions = this.menuOptions, title = this.title, suffixIcon = this.suffixIcon, prefixIcon = this.prefixIcon;
    var slots = this.slots, size = this.size, state = this.state, border = this.border, showIcon = this.showIcon, round = this.round, clickOutside = this.clickOutside, visible = this.visible;
    var params = {
      visible: state.visible
    };
    var triggerElm = null;
    var triggerClass = "tiny-dropdown__trigger tiny-dropdown-trigger";
    var addVisibleClass = state.visibleIsBoolean ? visible : state.visible;
    var visibleClass = addVisibleClass ? "tiny-dropdown--visible tiny-dropdown-visible" : "";
    var IconDown = suffixIcon || ((_state$designConfig = state.designConfig) == null ? void 0 : (_state$designConfig$i = _state$designConfig.icons) == null ? void 0 : _state$designConfig$i.dropdownIcon) || iconDownWard();
    var IconPre = prefixIcon;
    var ButtonIconDown = ((_state$designConfig2 = state.designConfig) == null ? void 0 : (_state$designConfig2$ = _state$designConfig2.icons) == null ? void 0 : _state$designConfig2$.dropdownIcon) || iconDownWard();
    var defaultSlot = slots.default && slots.default(params);
    if (splitButton) {
      triggerElm = h2("tiny-button-group", [h2("tiny-button", {
        "attrs": {
          "type": type,
          "size": size,
          "disabled": disabled
        },
        "on": {
          "click": handleMainButtonClick
        },
        "class": "tiny-dropdown__title-button"
      }, [defaultSlot || h2("span", [title])]), h2("tiny-button", {
        "ref": "trigger",
        "attrs": {
          "type": type,
          "size": size,
          "disabled": disabled,
          "reset-time": 0
        },
        "class": "tiny-dropdown__caret-button " + triggerClass
      }, [h2(ButtonIconDown, {
        "class": visibleClass
      })])]);
    } else {
      var _defaultSlot$;
      var suffixSlot = slots["suffix-icon"] && slots["suffix-icon"]();
      var prefixSlot = slots["prefix-icon"] && slots["prefix-icon"]();
      var vnodeData = defaultSlot && ((_defaultSlot$ = defaultSlot[0]) == null ? void 0 : _defaultSlot$.data) || {};
      var _vnodeData$attrs = vnodeData.attrs, attrs = _vnodeData$attrs === void 0 ? {} : _vnodeData$attrs;
      if (disabled && !attrs.disabled) {
        attrs.disabled = true;
        vnodeData.attrs = attrs;
      }
      var suffixInner = showIcon ? h2("span", {
        "class": "tiny-dropdown__suffix-inner " + visibleClass
      }, [suffixSlot || h2(IconDown)]) : "";
      var prefixInner = prefixIcon || prefixSlot ? h2("span", {
        "class": "tiny-dropdown__prefix-inner " + visibleClass
      }, [prefixSlot || h2(IconPre)]) : "";
      var defaultTriggerElm = defaultSlot || title ? h2("span", {
        "class": "tiny-dropdown__title"
      }, [defaultSlot || title]) : null;
      triggerElm = border ? h2("tiny-button", {
        "ref": "trigger",
        "attrs": {
          "round": round,
          "size": size,
          "disabled": disabled,
          "type": type,
          "reset-time": 0
        },
        "class": "tiny-dropdown__border " + (state.visible ? "is-expand" : "") + (showIcon ? " is-show-icon " : "") + " " + triggerClass
      }, [prefixInner, defaultTriggerElm, suffixInner]) : h2("span", {
        "ref": "trigger",
        "class": "is-text" + (state.visible ? " is-expand" : " is-hide") + (disabled ? " is-disabled" : "") + " " + triggerClass
      }, [prefixInner, defaultTriggerElm, suffixInner]);
    }
    var defaulMenuElm = h2("tiny-dropdown-menu", {
      "attrs": {
        "options": menuOptions.options,
        "text-field": menuOptions.textField || menuOptions["text-field"],
        "popper-class": menuOptions.popperClass || menuOptions["popper-class"],
        "placement": menuOptions.placement
      }
    });
    var menuElm = disabled ? null : slots.dropdown && slots.dropdown() || defaulMenuElm;
    return h2("div", {
      "class": "tiny-dropdown",
      "directives": [{
        name: "clickoutside",
        value: !state.visibleIsBoolean && clickOutside
      }],
      "attrs": {
        "aria-disabled": disabled
      }
    }, [triggerElm, menuElm]);
  }
});
var __vue2_render, __vue2_staticRenderFns;
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, __vue2_render, __vue2_staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
